@@ -1,11 +1,15 @@
 use rusty_engine::prelude::*;
 
 fn main() {
-    println!("Note: If you are not running with `--release`, it may take several seconds for each song to load.");
     let mut game = Game::new();
     game.game_state_mut()
         .timer_map
         .insert("music change timer".into(), Timer::from_seconds(30.0, true));
+    let _ = game.add_text_actor(
+        "msg",
+        "If you are not running with \"--release\", it may take several seconds for each song to load.",
+    );
+
     game.run(logic);
 }
 
@@ -16,7 +20,7 @@ fn logic(game_state: &mut GameState) {
         game_state.bool_map.insert("music started".into(), true);
         game_state
             .audio_manager
-            .play_music(MusicPreset::MysteriousMagic);
+            .play_music(MusicPreset::MysteriousMagic, 1.0);
     }
     if game_state
         .timer_map
@@ -28,7 +32,9 @@ fn logic(game_state: &mut GameState) {
         if game_state.bool_map.get("music changed").is_none() {
             println!("Switching to Classy8Bit...forever. Press Esc on the GUI Window or Ctrl-C in the terminal to quit.");
             game_state.bool_map.insert("music changed".into(), true);
-            game_state.audio_manager.play_music(MusicPreset::Classy8Bit);
+            game_state
+                .audio_manager
+                .play_music(MusicPreset::Classy8Bit, 1.0);
         }
     }
 }
