@@ -17,12 +17,27 @@ pub struct CollisionEvent {
     pub pair: CollisionPair,
 }
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Copy)]
 pub enum CollisionState {
     Begin,
     End,
 }
 
+impl CollisionState {
+    pub fn is_begin(&self) -> bool {
+        match self {
+            CollisionState::Begin => true,
+            CollisionState::End => false,
+        }
+    }
+    pub fn is_end(&self) -> bool {
+        match self {
+            CollisionState::Begin => false,
+            CollisionState::End => true,
+        }
+    }
+}
+
 #[derive(Debug, Default, Eq, Hash, Clone)]
 pub struct CollisionPair(String, String);
 
@@ -32,6 +47,13 @@ impl PartialEq for CollisionPair {
     }
 }
 
+impl CollisionPair {
+    pub fn contains<T: Into<String>>(&self, label: T) -> bool {
+        let label = label.into();
+        (self.0 == label) || (self.1 == label)
+    }
+}
+
 fn collision_detection(
     mut existing_collisions: Local<HashSet<CollisionPair>>,
     mut collision_events: EventWriter<CollisionEvent>,
